/*
 * Copyright Aduna (http://www.aduna-software.com/) (c) 1997-2007.
 *
 * Licensed under the Aduna BSD-style license.
 */

package info.aduna.collections.iterators;

import java.util.Iterator;

import info.aduna.iteration.DelayedIteration;
import info.aduna.iteration.Iteration;

/**
 * An iterator that delays the creation of the underlying iterator until it is
 * being accessed. This is mainly useful for situations where iterator creation
 * adds considerable overhead but where the iterator may not actually be used,
 * or where a created iterator consumes scarce resources like JDBC-connections
 * or memory. Subclasses must implement the <tt>createIterator</tt> method,
 * which is called once when the iterator is first needed.
 */
public abstract class DelayedIterator<E> extends DelayedIteration<E, RuntimeException> implements
		CloseableIterator<E>
{

	protected final Iteration<? extends E, RuntimeException> createIteration()
		throws RuntimeException
	{
		return new IteratorIteration<E, RuntimeException>(createIterator());
	}

	/**
	 * Creates the iterator that should be iterated over. This method is called
	 * only once, when the iterator is first needed.
	 */
	protected abstract Iterator<? extends E> createIterator();

}
