/*
 * Copyright Aduna (http://www.aduna-software.com/) (c) 1997-2007.
 *
 * Licensed under the Aduna BSD-style license.
 */

package info.aduna.collections.iterators;

import java.util.Iterator;

import info.aduna.iteration.IntersectIteration;

/**
 * An iterator that returns the intersection of the results of two iterators.
 * Optionally, the iterator can be configured to filter duplicates from the
 * returned elements.
 * <p>
 * Note that duplicates can also be filtered by wrapping this iterator in a
 * {@link DistinctIterator}, but that has a bit more overhead as it adds a
 * second hash table lookup.
 */
public class IntersectIterator<E> extends IntersectIteration<E, RuntimeException> implements
		CloseableIterator<E>
{

	/**
	 * Creates a new IntersectIterator that returns the intersection of the
	 * results of two iterators. By default, duplicates are <em>not</em>
	 * filtered from the results.
	 * 
	 * @param arg1
	 *        An iterator containing the first set of elements.
	 * @param arg2
	 *        An iterator containing the second set of elements.
	 */
	public IntersectIterator(Iterator<? extends E> arg1, Iterator<? extends E> arg2) {
		this(arg1, arg2, false);
	}

	/**
	 * Creates a new IntersectIterator that returns the intersection of the
	 * results of two iterators.
	 * 
	 * @param arg1
	 *        An iterator containing the first set of elements.
	 * @param arg2
	 *        An iterator containing the second set of elements.
	 * @param distinct
	 *        Flag indicating whether duplicate elements should be filtered from
	 *        the result.
	 */
	public IntersectIterator(Iterator<? extends E> arg1, Iterator<? extends E> arg2, boolean distinct) {
		super(new IteratorIteration<E, RuntimeException>(arg1),
				new IteratorIteration<E, RuntimeException>(arg2), distinct);
	}
}
