/*
 * Copyright Aduna (http://www.aduna-software.com/) (c) 2007.
 *
 * Licensed under the Aduna BSD-style license.
 */

package info.aduna.collections.iterators;

import java.util.Iterator;

import info.aduna.iteration.CloseableIteration;

/**
 * Bridge between the iterators in this package and the iterations in package
 * info.aduna.iteration. Most iterator classes in this package use this bridge
 * class to piggy back on the implemented iteration functionality.
 * 
 * @author Arjohn Kampman
 */
class IteratorIteration<E, X extends Exception> implements CloseableIteration<E, X> {

	private Iterator<? extends E> iter;

	public IteratorIteration(Iterator<? extends E> iter) {
		this.iter = iter;
	}

	public boolean hasNext() {
		return iter.hasNext();
	}

	public E next() {
		return iter.next();
	}

	public void remove() {
		iter.remove();
	}

	public void close() {
		Iterators.closeCloseable(iter);
	}
}
