/*
 * Copyright Aduna (http://www.aduna-software.com/) (c) 1997-2007.
 *
 * Licensed under the Aduna BSD-style license.
 */

package info.aduna.collections.iterators;

import java.util.Iterator;

import info.aduna.iteration.IterationWrapper;

/**
 * Abstract superclass for iterators that wrap another iterator. The abstract
 * class <tt>IteratorWrapper</tt> itself provides default methods that forward
 * method calls to the wrapped iterator, closing itself when exhausted.
 * Subclasses of <tt>IteratorWrapper</tt> should override some of these
 * methods and may also provide additional methods and fields.
 */
public class IteratorWrapper<E> extends IterationWrapper<E, RuntimeException> implements CloseableIterator<E>
{

	/**
	 * Creates a new IteratorWrapper that operates on the supplied iterator.
	 * 
	 * @param iter
	 *        The wrapped iterator for this <tt>IteratorWrapper</tt>, must not
	 *        be <tt>null</tt>.
	 */
	public IteratorWrapper(Iterator<? extends E> iter) {
		super(new IteratorIteration<E, RuntimeException>(iter));
	}
}
