/*
 * Copyright Aduna (http://www.aduna-software.com/) (c) 1997-2007.
 *
 * Licensed under the Aduna BSD-style license.
 */

package info.aduna.collections.iterators;

import java.util.Iterator;

import info.aduna.iteration.LimitIteration;

/**
 * An iterator that limits the amount of elements that it returns from an
 * underlying iterator to a fixed amount. This class returns the first
 * <tt>limit</tt> elements from the underlying iterator and drops the rest.
 */
public class LimitIterator<E> extends LimitIteration<E, RuntimeException> implements CloseableIterator<E> {

	/*--------------*
	 * Constructors *
	 *--------------*/

	/**
	 * Creates a new LimitIterator.
	 * 
	 * @param iter
	 *        The underlying iterator, must not be <tt>null</tt>.
	 * @param limit
	 *        The number of query answers to return, must be larger than 0.
	 */
	public LimitIterator(Iterator<? extends E> iter, int limit) {
		super(new IteratorIteration<E, RuntimeException>(iter), limit);
	}
}
