/*
 * Copyright Aduna (http://www.aduna-software.com/) (c) 1997-2007.
 *
 * Licensed under the Aduna BSD-style license.
 */

package info.aduna.collections.iterators;

import java.util.Iterator;

import info.aduna.concurrent.locks.Lock;
import info.aduna.iteration.LockingIteration;

/**
 * An iterator that holds on to a lock until the iterator is closed. Upon
 * closing, the underlying iterator is closed before the lock is released.
 */
public class LockingIterator<E> extends LockingIteration<E, RuntimeException> implements CloseableIterator<E>
{

	/**
	 * Creates a new LockingIterator.
	 * 
	 * @param lock
	 *        The lock to release when the itererator is closed, must not be
	 *        <tt>null</tt>.
	 * @param iter
	 *        The underlying iterator, must not be <tt>null</tt>.
	 */
	public LockingIterator(Lock lock, Iterator<? extends E> iter) {
		super(lock, new IteratorIteration<E, RuntimeException>(iter));
	}
}
