/*
 * Copyright Aduna (http://www.aduna-software.com/) (c) 1997-2007.
 *
 * Licensed under the Aduna BSD-style license.
 */

package info.aduna.collections.iterators;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;

import info.aduna.iteration.Iteration;
import info.aduna.iteration.UnionIteration;

/**
 * An iterator that returns the bag union of the results of a number of
 * iterators. Note that the result of the iterator is a bag, not a set. The
 * UnionIterator does not do any duplicate filtering.
 */
public class UnionIterator<E> extends UnionIteration<E, RuntimeException> implements CloseableIterator<E> {

	/**
	 * Creates a new UnionIterator that returns the bag union of the results of a
	 * number of iterators.
	 * 
	 * @param args
	 *        The iterators containing the elements to iterate over.
	 */
	public UnionIterator(Iterator<? extends E>... args) {
		this(Arrays.asList(args));
	}

	/**
	 * Creates a new UnionIterator that returns the bag union of the results of a
	 * number of iterators.
	 * 
	 * @param args
	 *        The iterators containing the elements to iterate over.
	 */
	public UnionIterator(Iterable<? extends Iterator<? extends E>> args) {
		super(asIterations(args));
	}

	private static <E> List<Iteration<? extends E, RuntimeException>> asIterations(
			Iterable<? extends Iterator<? extends E>> args)
	{
		List<Iteration<? extends E, RuntimeException>> result = new ArrayList<Iteration<? extends E, RuntimeException>>();
		for (Iterator<? extends E> iterator : args) {
			result.add(new IteratorIteration<E, RuntimeException>(iterator));
		}
		return result;
	}
}
